import 'package:desktop_ui/constants.dart';
import 'package:desktop_ui/desktop_ui.dart';
import 'package:flutter/material.dart';

class EasyBadge extends StatelessWidget {
  /// 徽标数
  const EasyBadge({
    Key? key,
    this.count = 0,
    this.text,
    this.color,
    this.dot = false,
    this.overflowCount = 99,
    this.showZero = false,
    this.type = EasyThemeType.error,
    required this.child,
  }) : super(key: key);

  /// 显示的数字值
  final int count;

  /// 展示封顶的数字值
  final int? overflowCount;

  /// 当数值为 0 时，是否展示 Badge
  final bool? showZero;

  /// 自定义显示内容，优先级高于 count。
  final String? text;

  /// 定义颜色
  final Color? color;

  /// 不展示数字，只有一个小红点
  final bool? dot;

  /// 颜色风格，如果设置了 color ，则被 color 覆盖。默认：[EasyThemeType.error]
  final EasyThemeType? type;

  final Widget child;

  BoxConstraints _getBoxConstraints() {
    bool isShow = count > 0 || showZero!;
    double _minW = 0, _maxW = 0, _minH = 0, _maxH = 0;
    if (isShow) {
      if (dot != null && dot!) {
        _minW = 10;
        _maxW = 10;
        _minH = 10;
        _maxH = 10;
        // return const BoxConstraints(
        //   minWidth: 8,
        //   minHeight: 8,
        //   maxHeight: 8,
        //   maxWidth: 8,
        // );
      } else {
        _minW = 20;
        _maxW = 20;
        _minH = 20;
        _maxH = 20;
      }
    }

    return BoxConstraints(
      minWidth: _minW,
      maxWidth: _maxW,
      minHeight: _minH,
      maxHeight: _maxH,
    );
  }

  BoxDecoration _getBoxDecoration() {
    return BoxDecoration(
      color: iError,
      borderRadius: BorderRadius.circular(100),
    );
  }

  Widget _renderContent() {
    bool isDot = dot != null && dot!;
    return Container(
      constraints: _getBoxConstraints(),
      decoration: _getBoxDecoration(),
      alignment: Alignment.center,
      child: isDot
          ? const Text('')
          : Text(
              '$count',
              style: const TextStyle(
                color: iWhite,
                fontSize: iFontSizeMini,
              ),
            ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: iGapAllSmall,
      child: Stack(
        clipBehavior: Clip.none,
        children: [
          child,
          Positioned(
            top: -iDefaultGap,
            right: -iDefaultGap,
            child: _renderContent(),
          ),
        ],
      ),
    );
  }
}
