import 'package:desktop_ui/components/icon.dart';
import 'package:desktop_ui/constants.dart';
import 'package:desktop_ui/enums/button.dart';
import 'package:desktop_ui/utils/button.dart';
import 'package:flutter/material.dart';

/// 按钮 - button
class EasyButton extends StatelessWidget {
  const EasyButton({
    Key? key,
    this.text,
    required this.onClick,
    this.type,
    this.ghost,
    this.disabled,
    this.block,
    this.icon,
    this.shape,
    this.semanticLabel,
    this.size,
  }) : super(key: key);

  final String? text;
  final VoidCallback? onClick;

  /// 按钮类型
  final EasyButtonType? type;

  /// 是否是幽灵按钮
  final bool? ghost;

  /// 是否是禁用
  final bool? disabled;

  /// 是否是铺满父级元素宽度
  final bool? block;

  /// 按钮图标
  final IconData? icon;

  /// 按钮形状，默认为：round
  final EasyButtonShape? shape;

  /// 按钮大小，默认：middle
  final EasyButtonSize? size;

  /// 图标语义描述信息，无障碍信息
  final String? semanticLabel;

  @override
  Widget build(BuildContext context) {
    Size _size = MediaQuery.of(context).size;
    Widget _child = Text(
      text ?? '',
      style: TextStyle(
        fontSize: getButtonFontSize(size),
        color: getButtonTextColor(type, ghost),
      ),
    );
    // 图标按钮
    bool isIconBtn = false;
    if (icon != null) {
      isIconBtn = true;
      _child = EasyIcon(
        icon,
        size: getButtonFontSize(size),
        color: getButtonTextColor(type, ghost),
      );
    }
    double buttonHeight = getButtonHeight(size);
    // 是否是圆形
    bool isCricle = shape != null && shape! == EasyButtonShape.circle;
    return Semantics(
      label: semanticLabel,
      child: ElevatedButton(
        child: _child,
        onPressed: onClick,
        style: ButtonStyle(
          minimumSize: MaterialStateProperty.all(
            Size(block != null && block! ? _size.width : buttonHeight, buttonHeight),
          ),
          maximumSize: MaterialStateProperty.all(Size(_size.width, buttonHeight)),
          padding: MaterialStateProperty.all(isIconBtn ? iGapZero : iGapHorizontalLarger),
          shadowColor: MaterialStateProperty.all(iTransparent),
          backgroundColor: MaterialStateProperty.all(getButtonBackgroundColor(type, ghost)),
          shape: MaterialStateProperty.all(
            RoundedRectangleBorder(
              borderRadius: BorderRadius.all(Radius.circular(isCricle ? buttonHeight : 2)),
            ),
          ),
          side: MaterialStateProperty.all(getButtonBorderSide(type, ghost)),
        ),
      ),
    );
  }
}
