import 'package:desktop_ui/constants.dart';
import 'package:desktop_ui/desktop_ui.dart';
import 'package:flutter/material.dart';

class EasyCard extends StatefulWidget {
  /// 卡片
  const EasyCard({
    Key? key,
    this.title,
    this.icon,
    this.extra,
    this.border = true,
    required this.child,
    this.shadow = false,
    this.padding = iDefaultGap * 2,
    this.onClick,
  }) : super(key: key);

  final String? title;
  final IconData? icon;

  /// 是否有边框
  final bool? border;

  /// 是否有阴影
  final bool? shadow;

  /// header 额外内容
  final Widget? extra;

  /// 子节点
  final Widget child;

  /// 卡片内部的间距，默认：10
  final double? padding;

  final VoidCallback? onClick;

  @override
  State<EasyCard> createState() => _EasyCardState();
}

class _EasyCardState extends State<EasyCard> {
  bool isHover = false;
  List<Widget> _renderHeader() {
    List<Widget> _list = <Widget>[];
    bool haveIcon = widget.icon != null;
    bool haveExtra = widget.extra != null;
    Widget _title = Text(
      widget.title!,
      style: iTitleTextBoldStyle,
    );
    if (haveIcon) {
      _list.add(Row(
        children: [
          Padding(
            padding: const EdgeInsets.only(right: iDefaultGap),
            child: EasyIcon(
              widget.icon,
              size: iFontSizeMiddle,
            ),
          ),
          _title,
        ],
      ));
    } else {
      _list.add(_title);
    }
    if (haveExtra) {
      _list.add(widget.extra!);
    }
    return _list;
  }

  @override
  void initState() {
    super.initState();
    isHover = false;
  }

  void _onHover(bool flag) {
    setState(() {
      isHover = flag;
    });
  }

  List<Widget> _renderChild(Size size) {
    List<Widget> _list = <Widget>[];
    bool haveTitle = widget.title != null;

    if (haveTitle) {
      _list.add(Container(
        width: size.width,
        padding: iGapAll,
        decoration: const BoxDecoration(
          border: Border(
            bottom: BorderSide(color: iBorderColor, width: 1.0),
          ),
        ),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: _renderHeader(),
        ),
      ));
    }
    _list.add(Container(
      width: size.width,
      padding: iGapAll,
      child: widget.child,
    ));
    return _list;
  }

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    bool isBorder = widget.border != null && widget.border!;
    bool haveShadow = widget.shadow != null && widget.shadow!;
    return Container(
      width: size.width,
      decoration: BoxDecoration(
        color: iWhite,
        border: isBorder ? iBorder : iBorderNone,
        borderRadius: iBorderRadiusLarger,
        boxShadow: haveShadow || isHover ? iBoxShadow : null,
      ),
      child: InkWell(
        onHover: _onHover,
        hoverColor: iGray,
        onTap: widget.onClick ?? () {},
        child: Column(
          children: _renderChild(size),
        ),
      ),
    );
  }
}
