import 'package:desktop_ui/constants.dart';
import 'package:desktop_ui/desktop_ui.dart';
import 'package:flutter/material.dart';

class EasyCell extends StatefulWidget {
  /// 单元格
  const EasyCell({
    Key? key,
    required this.title,
    this.label,
    this.value,
    this.extra,
    this.link,
    this.onClick,
  }) : super(key: key);

  /// 标题
  final String title;

  /// 提示信息
  final String? label;

  /// 值
  final String? value;

  /// 额外的内容，与 value 互斥，优先级比 value 高
  final Widget? extra;

  /// 是否是链接
  final bool? link;

  /// 点击事件
  final VoidCallback? onClick;

  @override
  State<EasyCell> createState() => _EasyCellState();
}

class _EasyCellState extends State<EasyCell> {
  late Color _bgColor;

  List<Widget> _renderTitle() {
    List<Widget> _list = <Widget>[];
    _list.add(Text(
      widget.title,
      style: iTitleTextStyle,
    ));
    if (widget.label != null) {
      _list.add(Text(
        '${widget.label}',
        style: iSubTitleTextStyle,
      ));
    }
    return _list;
  }

  List<Widget> _renderExtraValue() {
    List<Widget> _list = <Widget>[];
    if (widget.extra != null) {
      _list.add(widget.extra!);
    } else if (widget.value != null) {
      _list.add(Text(
        '${widget.value}',
        style: const TextStyle(fontSize: iFontSizeSmall, color: iContentColor),
      ));
    }
    if (widget.link != null && widget.link!) {
      _list.add(const EasyIcon(
        EasyIconData.arrowRight,
        size: 16,
        color: iContentColor,
      ));
    }
    return _list;
  }

  Widget _renderContent() {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: [
        Column(
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: _renderTitle(),
        ),
        Row(
          mainAxisAlignment: MainAxisAlignment.end,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: _renderExtraValue(),
        ),
      ],
    );
  }

  @override
  void initState() {
    super.initState();
    _bgColor = iWhite;
  }

  void _onHover(bool flag) {
    setState(() {
      _bgColor = flag ? iGrayLighter : iWhite;
    });
  }

  @override
  Widget build(BuildContext context) {
    Size _size = MediaQuery.of(context).size;
    return Container(
      // height: iCellHeight,
      width: _size.width,
      padding: iGapAll,
      decoration: BoxDecoration(
        color: _bgColor,
      ),
      constraints: BoxConstraints(minHeight: iCellHeight),
      child: InkWell(
        onHover: _onHover,
        hoverColor: iGray,
        onTap: widget.onClick ?? () {},
        child: _renderContent(),
      ),
    );
  }
}
