import 'package:desktop_ui/constants.dart';
import 'package:flutter/material.dart';

enum DividerOrientation {
  left,
  center,
  right,
}

double borderHeight = 1.0;

class EasyDivider extends StatelessWidget {
  /// 分割线
  const EasyDivider({
    Key? key,
    this.dashed,
    this.text,
    this.orientation,
  }) : super(key: key);

  /// 是否是虚线
  final bool? dashed;

  /// 显示标题
  final String? text;

  /// 标题位置，默认居中
  final DividerOrientation? orientation;

  /// 生成实线
  Widget _renderSolid() {
    return LayoutBuilder(
      builder: (BuildContext context, BoxConstraints constraints) {
        return SizedBox(
          width: constraints.biggest.width,
          height: borderHeight,
          child: Container(
            decoration: const BoxDecoration(color: iDividerColor),
          ),
        );
      },
    );
  }

  /// 生成虚线
  Widget _renderDashed() {
    return LayoutBuilder(
      builder: (BuildContext context, BoxConstraints constraints) {
        final boxWidth = constraints.biggest.width;
        double dashWidth = 3.0;
        double dashHeight = 1.0;
        final dashCount = (boxWidth / (2 * dashWidth)).floor();
        return Flex(
          children: List.generate(dashCount, (_) {
            return SizedBox(
              width: dashWidth,
              height: dashHeight,
              child: const DecoratedBox(
                decoration: BoxDecoration(color: iDividerColor),
              ),
            );
          }),
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          direction: Axis.horizontal,
        );
      },
    );
  }

  Widget _renderText() {
    return Padding(
      padding: text == '' ? const EdgeInsets.all(0) : iGapHorizontal,
      child: Text(
        text ?? '',
        style: const TextStyle(
          fontSize: iFontSize,
          fontWeight: iFontWeightBold,
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    bool isDashed = dashed != null && dashed!;
    int left = 1;
    int right = 1;
    switch (orientation) {
      case DividerOrientation.left:
        left = 1;
        right = 10;
        break;
      case DividerOrientation.right:
        left = 10;
        right = 1;
        break;
      default:
        break;
    }
    return SizedBox(
      width: size.width,
      height: iDividerHeight,
      child: Row(
        children: [
          Expanded(
            child: isDashed ? _renderDashed() : _renderSolid(),
            flex: left,
          ),
          _renderText(),
          Expanded(
            child: isDashed ? _renderDashed() : _renderSolid(),
            flex: right,
          ),
        ],
      ),
    );
  }
}
