import 'package:flutter/material.dart';

class EasyRow extends StatelessWidget {
  const EasyRow({
    Key? key,
    required this.children,
    this.gutter,
  }) : super(key: key);
  final List<EasyCol> children;

  /// 间距
  final double? gutter;

  List _dealToDouble() {
    List<Widget> _list = <Widget>[];
    List _doubleList = [];
    int len = 0;
    // 根据 span 不超过 24 处理为二维数组
    for (var i = 0; i < children.length; i++) {
      EasyCol item = children[i];
      Widget child = item.getChild();
      Map props = item.getProps();
      int span = props['span'];
      int offset = props['offset'];
      if (len + span + offset > 24) {
        _doubleList.add(List.from(_list));
        _list.clear();
        len = 0;
      }
      len = len + span + offset;
      _list.add(EasyCol(
        child: child,
        span: props['span'],
        offset: props['offset'],
      ));

      if (i == (children.length - 1)) {
        _doubleList.add(_list);
      }
    }
    return _doubleList;
  }

  double _calcSpanWidth(int len, double allWidth) {
    double _gutterWidth = len - 1 > 0 ? (len - 1) * (gutter ?? 0) : len * (gutter ?? 0);
    double spanWidth = (allWidth - _gutterWidth) / 24;
    return spanWidth;
  }

  List<Widget> dealCol(double allWidth) {
    List<Widget> list = <Widget>[];
    // 根据 span 不超过 24 处理为二维数组
    List doubleList = _dealToDouble();
    for (var j = 0; j < doubleList.length; j++) {
      List itemList = doubleList[j];
      double spanWidth = _calcSpanWidth(itemList.length, allWidth);
      for (var i = 0; i < itemList.length; i++) {
        Widget child = itemList[i].getChild();
        Map props = itemList[i].getProps();
        list.add(EasyCol(
          child: child,
          span: props['span'],
          offset: props['offset'],
          spanWidth: spanWidth,
        ));
      }
    }

    return list;
  }

  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(
      builder: (BuildContext context, BoxConstraints constraints) {
        double parantWidth = constraints.biggest.width;
        return SizedBox(
          width: parantWidth,
          child: Wrap(
            spacing: gutter ?? 0,
            runSpacing: gutter ?? 0,
            children: dealCol(parantWidth),
          ),
        );
      },
    );
  }
}

class EasyCol extends StatelessWidget {
  const EasyCol({
    Key? key,
    required this.child,
    this.span,
    this.offset,
    this.spanWidth,
  }) : super(key: key);

  /// 栅格数，1-24， 默认：24
  final int? span;

  /// 栅格左侧间隔数
  final int? offset;

  final double? spanWidth;

  /// 子节点
  final Widget child;

  Widget getChild() {
    return child;
  }

  Map getProps() {
    return {
      'offset': offset ?? 0,
      'span': span ?? 24,
    };
  }

  double _dealBoxWidth() {
    return (span ?? 24) * (spanWidth ?? 0);
  }

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: _dealBoxWidth(),
      child: child,
    );
  }
}
