import 'package:desktop_ui/constants.dart';
import 'package:desktop_ui/enums/common.dart';
import 'package:flutter/material.dart';

enum EasySpaceSize {
  small,
  middle,
  larger,
}

/// 间距组件，支持：横向，竖向
class EasySpace extends StatelessWidget {
  const EasySpace({
    Key? key,
    required this.children,
    this.direction,
    this.size,
    this.wrap,
  }) : super(key: key);

  /// 子节点
  final List<Widget> children;

  /// 方向
  final EasyDirectionType? direction;

  /// 间距大小
  final EasySpaceSize? size;

  /// 是否自动换行，仅在 horizontal 模式下有效
  final bool? wrap;

  EdgeInsetsGeometry _getGap() {
    EdgeInsetsGeometry _gapBottom = iGapBottom;
    EdgeInsetsGeometry _gapRight = iGapRight;
    EdgeInsetsGeometry _gapWrap = const EdgeInsets.only(bottom: iDefaultGap * 2, right: iDefaultGap * 2);
    switch (size) {
      case EasySpaceSize.small:
        _gapBottom = iGapBottomSmall;
        _gapRight = iGapRightSmall;
        _gapWrap = const EdgeInsets.only(bottom: iDefaultGap, right: iDefaultGap);
        break;
      case EasySpaceSize.middle:
        _gapBottom = iGapBottomMiddle;
        _gapRight = iGapRightMiddle;
        _gapWrap = const EdgeInsets.only(bottom: iDefaultGap * 3, right: iDefaultGap * 3);
        break;
      case EasySpaceSize.larger:
        _gapBottom = iGapBottomLarger;
        _gapRight = iGapRightLarger;
        _gapWrap = const EdgeInsets.only(bottom: iDefaultGap * 4, right: iDefaultGap * 4);
        break;
      default:
        break;
    }
    bool isVertical = direction == EasyDirectionType.vertical;
    return isVertical
        ? _gapBottom
        : wrap != null && wrap!
            ? _gapWrap
            : _gapRight;
  }

  List<Widget> _buildChildren() {
    List<Widget> _list = <Widget>[];
    for (var i = 0; i < children.length; i++) {
      _list.add(Padding(
        padding: _getGap(),
        child: children[i],
      ));
    }
    return _list;
  }

  @override
  Widget build(BuildContext context) {
    return direction == EasyDirectionType.vertical
        ? Column(
            children: _buildChildren(),
          )
        : wrap != null && wrap!
            ? Wrap(
                children: _buildChildren(),
              )
            : Row(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: _buildChildren(),
              );
  }
}
