// 按钮的处理函数
import 'package:desktop_ui/constants.dart';
import 'package:desktop_ui/enums/button.dart';
import 'package:flutter/material.dart';

/// 获取按钮高度
double getButtonHeight(EasyButtonSize? size) {
  double height = iButtonHeight;
  if (size == null) return height;
  switch (size) {
    case EasyButtonSize.small:
      height = iButtonHeightSmall;
      break;
    case EasyButtonSize.middle:
      height = iButtonHeightMiddle;
      break;
    case EasyButtonSize.larger:
      height = iButtonHeightLarger;
      break;
  }
  return height;
}

/// 获取按钮字体大小
double getButtonFontSize(EasyButtonSize? size) {
  double fontsize = iFontSize;
  if (size == null) return fontsize;
  switch (size) {
    case EasyButtonSize.small:
      fontsize = iFontSizeSmall;
      break;
    case EasyButtonSize.middle:
      fontsize = iFontSizeMiddle;
      break;
    case EasyButtonSize.larger:
      fontsize = iFontSizeLarger;
      break;
  }
  return fontsize;
}

/// 获取按钮的背景颜色
Color getButtonBackgroundColor(EasyButtonType? type, bool? ghost) {
  bool isGhost = ghost != null && ghost;
  if (isGhost) return iTransparent;
  Color bgColor = iWhite;
  if (type == null) return bgColor;
  switch (type) {
    case EasyButtonType.primary:
      bgColor = iPrimary;
      break;
    case EasyButtonType.info:
      bgColor = iInfo;
      break;
    case EasyButtonType.success:
      bgColor = iSuccess;
      break;
    case EasyButtonType.warn:
      bgColor = iWarn;
      break;
    case EasyButtonType.error:
      bgColor = iError;
      break;
    case EasyButtonType.text:
      bgColor = iWhite;
      break;
  }
  return bgColor;
}

/// 获取按钮的文本颜色
Color getButtonTextColor(EasyButtonType? type, bool? ghost) {
  Color textColor = iBlack;
  if (type == null) return textColor;
  bool isGhost = ghost != null && ghost;
  switch (type) {
    case EasyButtonType.primary:
      textColor = isGhost ? iPrimary : iWhite;
      break;
    case EasyButtonType.info:
      textColor = isGhost ? iInfo : iWhite;
      break;
    case EasyButtonType.success:
      textColor = isGhost ? iSuccess : iWhite;
      break;
    case EasyButtonType.warn:
      textColor = isGhost ? iWarn : iWhite;
      break;
    case EasyButtonType.error:
      textColor = isGhost ? iError : iWhite;
      break;
    case EasyButtonType.text:
      textColor = iBlack;
      break;
    default:
      textColor = iBlack;
      break;
  }
  return textColor;
}

/// 获取按钮的边框 border
BorderSide getButtonBorderSide(EasyButtonType? type, bool? ghost) {
  BorderSide borderSide = const BorderSide(color: iBorderColor, width: 1.0);
  if (type == null) return borderSide;
  bool isGhost = ghost != null && ghost;
  switch (type) {
    case EasyButtonType.primary:
      borderSide = isGhost ? const BorderSide(color: iPrimary, width: 1.0) : BorderSide.none;
      break;
    case EasyButtonType.info:
      borderSide = isGhost ? const BorderSide(color: iInfo, width: 1.0) : BorderSide.none;
      break;
    case EasyButtonType.success:
      borderSide = isGhost ? const BorderSide(color: iSuccess, width: 1.0) : BorderSide.none;
      break;
    case EasyButtonType.warn:
      borderSide = isGhost ? const BorderSide(color: iWarn, width: 1.0) : BorderSide.none;
      break;
    case EasyButtonType.error:
      borderSide = isGhost ? const BorderSide(color: iError, width: 1.0) : BorderSide.none;
      break;
    case EasyButtonType.text:
      borderSide = BorderSide.none;
      break;
  }
  return borderSide;
}
