import 'package:desktop_ui/constants.dart';
import 'package:desktop_ui/enums/common.dart';
import 'package:desktop_ui/utils/common.dart';
import 'package:flutter/material.dart';

/// 根据文本等级返回字体大小
double getFontSize(EasyTextLevel? level) {
  if (level == null) return 14.0;
  double _fontSize;
  switch (level) {
    case EasyTextLevel.h1:
      _fontSize = 38.0;
      break;
    case EasyTextLevel.h2:
      _fontSize = 30.0;
      break;
    case EasyTextLevel.h3:
      _fontSize = 24.0;
      break;
    case EasyTextLevel.h4:
      _fontSize = 20.0;
      break;
    case EasyTextLevel.h5:
      _fontSize = 16.0;
      break;
    case EasyTextLevel.content:
      _fontSize = 14.0;
      break;
    default:
      _fontSize = 14.0;
      break;
  }
  return _fontSize;
}

/// 获取文本的装饰样式
TextDecoration getTextDecoration(bool? underline, bool? delete) {
  if (underline != null && underline) {
    return TextDecoration.underline;
  }
  if (delete != null && delete) {
    return TextDecoration.lineThrough;
  }
  return TextDecoration.none;
}

/// 获取文字截取方式
TextOverflow getTextOverflow(bool? ellipsis) {
  if (ellipsis == null) return TextOverflow.clip;
  return ellipsis ? TextOverflow.ellipsis : TextOverflow.clip;
}

/// 获取字重
FontWeight getFontWeight(bool? strong) {
  if (strong == null) return FontWeight.normal;
  return strong ? FontWeight.bold : FontWeight.normal;
}

/// 获取字体样式
FontStyle getFontStyle(bool? italic) {
  if (italic == null) return FontStyle.normal;
  return italic ? FontStyle.italic : FontStyle.normal;
}

/// 获取字体颜色
Color getTextColor(EasyThemeType? type, bool? disable, bool? mark) {
  if (disable != null && disable) return iGray;
  if (mark != null && mark) return iBlack;
  return getColorByThemeType(type);
}

/// 获取字体背景颜色
Color getTextBackgroundColor(EasyThemeType? type, bool? mark) {
  if (mark == null) return Colors.transparent;
  return type == null ? getColorByThemeType(EasyThemeType.warn) : getColorByThemeType(type);
}
